#!/bin/bash
# diag.sh
# Andrew Davison, Nov 2019, ad@fivedots.coe.psu.ac.th

# a temporary file to hold command output
OUTPUT=/tmp/output.sh.$$

# trap to delete temp output file
trap "rm $OUTPUT; exit" SIGHUP SIGINT SIGTERM


# display output
showMsg() {
  local t=${1-Output}   # title; default is "Output"
  local h=${2-10}       # height default 10
  local w=${3-40}       # width default 40
  dialog --backtitle "Dialog Example" \
         --keep-tite --clear  \
         --title "${t}" --msgbox "$(<$OUTPUT)" ${h} ${w}
}


showDate() {
  echo "Today is $(date) @ $(hostname -f)."  | tee $OUTPUT
  showMsg "Date and Time"
}


showWho() {
  who | tee $OUTPUT
  showMsg "Who is Here" 30 30
}


showPwd() {
  pwd | tee $OUTPUT
  showMsg "Working Directory"
}


# supply an array of strings as an argument;
# the function sets the global opts[] to the indicies of
# the selected options (starting at 1), and returns a
# count of the selected options (which may be 0)
getOptions() {
  local cmd=(dialog --backtitle "Dialog Example" 
              --separate-output  --checklist --keep-tite 
              "Select options:" 22 76 16)

  local options=("$@")
  local num=${#options[@]}

  # extend options array to be suitable for a dialog checklist
  local selects=()
  for((i=0;i<$num;i++)); do
    selects+=( $((i+1)) "${options[i]}" "off" )  # numbered options; all off
  done

  opts=$("${cmd[@]}" "${selects[@]}" 2>&1 >/dev/tty)
  local ret="$?"
#  echo $ret

  if [ "$ret" -eq 1 ]; then
    echo "Selection cancelled"
    return 0
  elif  [ "$ret" -ne 0 ]; then
    echo "Unknown error"
    return 0
  fi

  local IFS=$'\n'      # Change IFS locally to new line
  opts=($opts)         # split string into an array

  return "${#opts[@]}"    # count the number of selections
}  # end of getOptions()



# ----------------- main -----------------------

options=("Print the date"
         "Print the users who are currently log on"
         "Print the working directory")

getOptions "${options[@]}"
ret="$?"
# echo $ret
# echo "${opts[@]}"

if [ "$ret" -eq 0 ]; then
  echo -e "\nNo options selected"
  exit 0
fi


echo -e "\nOptions chosen:"
for (( i=0; i<$ret; i++ )); do
  idx=${opts[$i]}   # idx starts at 1
  echo -e "\n$idx. ${options[$((idx-1))]}"
  case $idx in
    1) showDate ;;
    2) showWho ;;
    3) showPwd ;;
    *) echo "??" ;;
  esac
done

# delete temp command output file
[ -f $OUTPUT ] && rm $OUTPUT

