#!/bin/bash
# opts.sh
# Andrew Davison, Nov 2019, ad@fivedots.coe.psu.ac.th


# terminal codes
RED=$(tput setaf 1)
YELLOW=$(tput setaf 3)
WHITE=$(tput setaf 7)

BOLD=$(tput bold)
REV=$(tput rev)

RESET=$(tput sgr0)

# the toggle ON/OFF strings
# ON="${BOLD}${RED}<--${RESET}"     # a red arrow
ON="${REV}*${RESET}"                # an inverted "*"
OFF=" "


# switch an option between on/off
toggle() {
  local -n arr=$1    # pass in togs[] array by reference
  local idx=$2       # index into array
  if [ "${arr[$idx]}" = "$ON" ]; then
    arr[$idx]="$OFF"
  else
    arr[$idx]="$ON"
  fi
}


# supply an array of strings as an argument;
# the function sets the global opts[] to the indicies of 
# the selected options (starting at 1), and returns a 
# count of the selected options (which may be 0)
getOptions() {
  local options=("$@")
  options+=("QUIT")    # add a quit option
  local num=${#options[@]}
  # echo $num
  
  # initialize the options on/off strings
  # as the togs[] array
  local togs=()
  for((i=0;i<$num;i++)); do
    togs+=( "$OFF" )
  done

  PS3='Please enter your selection: '
  local selects=()      # will hold options and on/off strings
  local isFinished=0
  while [ $isFinished -eq 0 ]
  do
    unset selects    # regenerate to show the new on/off values
    for((i=0;i<$num;i++)); do
      selects+=( "${options[i]} ${togs[i]}" )
    done
  
    clear
    printf "\nOptions:\n"
 #   TMOUT=5
    select sel in "${selects[@]}"
    do
      if ! [[ "$REPLY" =~ ^[0-9]+$ ]] ; then     # reject non-numbers
        echo "Invalid option; enter a number"
      elif [ "$REPLY" -ge 1 ] && [ "$REPLY" -lt $num ]; then
        # accept numbers that are in range (excluding quit)
        echo "You chose ${options[$((REPLY-1))]}"
        toggle togs $((REPLY-1))
        break
      elif [ "$REPLY" -eq $num ]; then     # process the quit option
        isFinished=1
        break
      else
        echo "Invalid option; choose 1-$num"
      fi
    done
    res="$?"

 #   TMOUT=0      #  switch off time-out
 #   if [ -z $REPLY ] ; then   # select terminated due to time-out
 #     isFinished=1
 #    fi
  done

  # store the indicies of the $ON options (starting at 1)
  # in the global opts[] array; onky look at the user's
  # options
  local count=0
  opts=()
  for((i=0;i<$num;i++)); do
    if [ "${togs[$i]}" = "$ON" ]; then    
      opts+=( "$((i+1))" )
      (( count++ ))
    fi
  done


  # return the number of selected options
  return $count
}  # end of getOptions()


# ------------- main ------------------------


options=("Print the date"
         "Print the users who are currently log on"
         "Print the working directory")


tput smcup     # save screen state

getOptions "${options[@]}"
ret="$?"

tput rmcup     # restore screen state

if [ "$ret" -eq 0 ]; then
  echo -e "\nNo options selected"
  exit 0
fi

echo -e "\nOptions chosen:"
for (( i=0; i<$ret; i++ )); do
  idx=${opts[$i]}      # idx starts at 1
  echo -e "\n$idx. ${options[$((idx-1))]}"
  case $idx in
    1) date ;;
    2) who ;;
    3) pwd ;;
    *) echo "??" ;;     # just to be safe
  esac
done


