#!/bin/bash
# yad.sh
# Andrew Davison, Nov 2019, ad@fivedots.coe.psu.ac.th

# a temporary file to hold command output
OUTPUT=/tmp/output.sh.$$

# trap to delete temp output file
trap "rm $OUTPUT; exit" SIGHUP SIGINT SIGTERM


# display output
showMsg() {
  local t=${1-Output}    # title
  local h=${2-100}       # height default 100
  local w=${3-450}       # width default 450
  yad --text-info --title "${t}" \
         --height ${h}  --width ${w}   \
         --button=OK:0   \
         --filename="$OUTPUT"

# alternative display format
# yad --info --title "${t}" \
#         --height ${h}  --width ${w}   \
#         --button=OK:0   \
#         --text="$(<$OUTPUT)" 
}


showDate() {
  echo "Today is $(date) @ $(hostname -f)."  | tee $OUTPUT
  showMsg "Date and Time"
}


showWho() {
  who | tee $OUTPUT
  showMsg "Who is Here" 200
}


showPwd() {
  pwd | tee $OUTPUT
  showMsg "Working Directory"
}

# supply an array of strings as an argument;
# the function sets the global opts[] to the indicies of
# the selected options (starting at 1), and returns a
# count of the selected options (which may be 0)
getOptions() {
  local options=("$@")
  local num=${#options[@]}

   # extend options array to be suitable for a yad checklist
  local selects=()
  for((i=0;i<$num;i++)); do
    selects+=( FALSE  $((i+1)) "${options[i]}" )  
        # all boxes unchecked; hidden row number which is returned;
        # numbers starts at 1
  done

  opts=$(yad --list  --title="Choices" \
             --image="select.png"  \
             --no-click  --on-top  \
             --text="Select options:" \
             --width=400 --height=200  \
             --column="Selected:CHK" --column="id:NUM" --column="Description" \
             --hide-column=2  --print-column=2  \
             --grid-lines=horiz  \
             --checklist "${selects[@]}")

  local ret="$?"
  opts=$(echo $opts | tr -d ' \n')    # clean up checklist output string

  if [ "$ret" -eq 1 ]; then
    echo "Selection cancelled"
    return 0
  elif  [ "$ret" -ne 0 ]; then
    echo "Unknown error"
    return 0
  fi

  local IFS="|"     # Change IFS locally to yad separator
  opts=($opts)      # split string into an array

  return "${#opts[@]}"    # count the number of selections
}  # end of getOptions()



# ----------------- main -----------------------

options=("Print the date"
         "Print the users who are currently log on"
         "Print the working directory")

getOptions "${options[@]}"
ret="$?"

if [ "$ret" -eq 0 ]; then
  echo -e "\nNo options selected"
  exit 0
fi


echo -e "\nOptions chosen:"
for (( i=0; i<$ret; i++ )); do
  idx=${opts[$i]}   # idx starts at 1
  echo -e "\n$idx. ${options[$((idx-1))]}"
  case $idx in
    1) showDate ;;
    2) showWho ;;
    3) showPwd ;;
    *) echo "??" ;;
  esac
done

# delete temp command output file
[ -f $OUTPUT ] && rm $OUTPUT

